/*
FriendCapability.java
Copyright (C) 2010  Belledonne Communications, Grenoble, France

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
*/

package org.linphone.core;

import androidx.annotation.Nullable;
import androidx.annotation.NonNull;

/**
* Enum describing the capabilities of a {@link Friend}, populated through<br/>
* presence subscribe/notify process. <br/>
* <br/>
*/
public enum FriendCapability {
    /**
    * No capabilities populated. <br/>
    * <br/>
    */
    None(0),

    /**
    * This friend can be invited in a Flexisip backend {@link ChatRoom}. <br/>
    * <br/>
    */
    GroupChat(1<<0),

    /**
    * This friend can be invited in a Flexisip backend end-to-end encrypted {@link ChatRoom}<br/>
    * . <br/>
    * <br/>
    */
    LimeX3Dh(1<<1),

    /**
    * This friend is able to delete ephemeral messages once they have expired. <br/>
    * <br/>
    */
    EphemeralMessages(1<<2);

    protected final int mValue;

    private FriendCapability (int value) {
        mValue = value;
    }

    static public FriendCapability fromInt(int value) throws RuntimeException {
        switch(value) {
        case 0: return None;
        case 1<<0: return GroupChat;
        case 1<<1: return LimeX3Dh;
        case 1<<2: return EphemeralMessages;
        default:
            throw new RuntimeException("Unhandled enum value " + value + " for FriendCapability");
        }
    }

    public int toInt() {
        return mValue;
    }
}
